<?php

/**
 * Plugin Name: EazyDocs Pro (Premium)
 * Description: Power-up the EazyDocs plugin with advanced controls and features
 * Plugin URI: #
 * Author: spider-themes
 * Author URI: http://spider-themes.net/
 * Version: 1.4.5

 * Update URI: https://api.freemius.com
 * License: GPL2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */
if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( function_exists( 'eaz_fs' ) ) {
    eaz_fs()->set_basename( true, __FILE__ );
} else {
    // DO NOT REMOVE THIS IF, IT IS ESSENTIAL FOR THE `function_exists` CALL ABOVE TO PROPERLY WORK.
    
    if ( !function_exists( 'eaz_fs' ) ) {
        // Create a helper function for easy SDK access.
        function eaz_fs()
        {
            global  $eaz_fs ;
            
            if ( !isset( $eaz_fs ) ) {
                // Include Freemius SDK.
                require_once dirname( __FILE__ ) . '/includes/fs/start.php';
                $eaz_fs = fs_dynamic_init( array(
                    'id'             => '10290',
                    'slug'           => 'eazydocs',
                    'premium_slug'   => 'eazydocs-pro',
                    'type'           => 'plugin',
                    'public_key'     => 'pk_8474e4208f0893a7b28c04faf5045',
                    'is_premium'     => true,
                    'has_addons'     => false,
                    'has_paid_plans' => true,
                    'trial'          => array(
                    'days'               => 7,
                    'is_require_payment' => true,
                ),
                    'menu'           => array(
                    'first-path' => 'plugins.php',
                    'slug'       => 'eazydocs',
                    'support'    => false,
                ),
                    'is_live'        => true,
                ) );
            }
            
            return $eaz_fs;
        }
        
        // Init Freemius.
        eaz_fs()->add_filter( 'deactivate_on_activation', '__return_false' );
        eaz_fs()->add_filter( 'hide_freemius_powered_by', '__return_true' );
        // Signal that SDK was initiated.
        do_action( 'eaz_fs_loaded' );
    }
    
    // ... Your plugin's main file logic ...
}


if ( !class_exists( 'EazyDocsPro' ) ) {
    require_once __DIR__ . '/vendor/autoload.php';
    /**
     * Class EazyDocsPro
     */
    class EazyDocsPro
    {
        /**
         * EazyDocs Version
         *
         * Holds the version of the plugin.
         *
         * @var string The plugin version.
         */
        const  version = '1.4.5' ;
        /**
         * @var mixed|null
         */
        private  $theme_dir_path ;
        /**
         * Constructor.
         *
         * Initialize the EazyDocs plugin
         *
         * @access public
         */
        public function __construct()
        {
            $this->define_constants();
            $this->core_includes();
            register_activation_hook( __FILE__, [ $this, 'activate' ] );
            add_action( 'init', [ $this, 'i18n' ] );
            add_action( 'plugins_loaded', [ $this, 'elementor_files' ] );
            add_action( 'plugins_loaded', [ $this, 'init_plugin' ] );
            add_action( 'wp_footer', function () {
                do_action( 'eazydocs_assistant' );
            } );
        }
        
        /**
         * Load Textdomain
         *
         * Load plugin localization files.
         *
         * @access public
         */
        public function i18n()
        {
            load_plugin_textdomain( 'eazydocs-pro', false, plugin_basename( dirname( __FILE__ ) ) . '/languages' );
        }
        
        /**
         * Include Files
         *
         * Load core files required to run the plugin.
         *
         * @access public
         */
        public function core_includes()
        {
            require_once __DIR__ . '/includes/functions.php';
            if ( eaz_fs()->is_plan( 'promax' ) ) {
                require_once __DIR__ . '/includes/Admin/analytics/Ajax_actions.php';
            }
            require_once __DIR__ . '/includes/notices.php';
            require_once __DIR__ . '/includes/User_Feedback.php';
            // Shortcodes
            require_once __DIR__ . '/shortcodes/one-page-shortcode.php';
            require_once __DIR__ . '/shortcodes/embed_post.php';
            include_once ABSPATH . 'wp-admin/includes/plugin.php';
            
            if ( is_plugin_active( 'eazydocs/eazydocs.php' ) ) {
                // Assistant
                new eazyDocsPro\Frontend\Search();
                new eazyDocsPro\Frontend\Assistant();
            }
        
        }
        
        function elementor_files()
        {
            if ( eaz_fs()->is_plan( 'promax' ) && did_action( 'elementor/loaded' ) ) {
                require_once __DIR__ . '/includes/template-library/template-library.php';
            }
        }
        
        /**
         * Define constants
         */
        public function define_constants()
        {
            define( 'EAZYDOCSPRO_VERSION', self::version );
            define( 'EAZYDOCSPRO_FILE', __FILE__ );
            define( 'EAZYDOCSPRO_PATH', __DIR__ );
            define( 'EAZYDOCSPRO_URL', plugins_url( '', EAZYDOCSPRO_FILE ) );
            define( 'EAZYDOCSPRO_ASSETS', EAZYDOCSPRO_URL . '/assets' );
            define( 'EAZYDOCSPRO_CSS', EAZYDOCSPRO_URL . '/assets/css' );
            define( 'EAZYDOCSPRO_FRONT_CSS', EAZYDOCSPRO_URL . '/assets/css/frontend' );
            define( 'EAZYDOCSPRO_IMG', EAZYDOCSPRO_URL . '/assets/images' );
            define( 'EAZYDOCSPRO_VEND', EAZYDOCSPRO_URL . '/assets/vendors' );
        }
        
        /**
         * Initializes a singleton instances
         * @return void
         */
        public static function init()
        {
            static  $instance = false ;
            if ( !$instance ) {
                $instance = new self();
            }
            return $instance;
        }
        
        /**
         * Initializes the plugin
         * @return void
         */
        public function init_plugin()
        {
            $this->theme_dir_path = apply_filters( 'eazydocspro_theme_dir_path', 'eazydocs-pro/' );
            
            if ( is_admin() ) {
                new eazyDocsPro\Admin\Admin_Actions();
                new eazyDocsPro\Duplicator\Parent_Duplicate();
                new eazyDocsPro\Duplicator\Section_Duplicate();
                new eazyDocsPro\Duplicator\Section_Child_Duplicate();
                new eazyDocsPro\Duplicator\Single_Duplicate();
                new eazyDocsPro\Admin\Assets();
                new eazyDocsPro\Admin\Feedback_Update();
                new eazyDocsPro\Admin\Feedback_Delete();
                new eazyDocsPro\Admin\Doc_Visibility();
                new eazyDocsPro\Admin\Doc_Section_Visibility();
                new eazyDocsPro\Admin\Doc_Sidebar();
                if ( eaz_fs()->is_plan( 'promax' ) && did_action( 'elementor/loaded' ) ) {
                    new eazyDocsPro\Template_library\Template_Library();
                }
            } else {
                new eazyDocsPro\Frontend\Frontend_Actions();
                new eazyDocsPro\Frontend\Assets();
                new eazyDocsPro\Frontend\Frontend();
            }
            
            if ( class_exists( 'EazyDocs' ) && ezd_is_premium() ) {
                new eazyDocsPro\Elementor\Config();
            }
        }
        
        /**
         * Do stuff upon plugin activation
         */
        public function activate()
        {
            //Insert the installation time into the database
            $installed = get_option( 'eazyDocsPro_installed' );
            if ( !$installed ) {
                update_option( 'eazyDocsPro_installed', time() );
            }
            update_option( 'EazyDocsPro_version', 'EAZYDOCSPRO_VERSION' );
            // Insert the eazydocs login page into the database if not exists
            
            if ( function_exists( 'ezd_get_page_by_title' ) && !ezd_get_page_by_title( 'Documentation Login' ) ) {
                // Create page object
                $docs_page = array(
                    'post_title'   => wp_strip_all_tags( 'Documentation Login' ),
                    'post_content' => '[ezd_login_form]',
                    'post_status'  => 'publish',
                    'post_author'  => 1,
                    'post_type'    => 'page',
                );
                wp_insert_post( $docs_page );
            }
            
            // when updating plugin send notice to admin that we did merge the docs views meta to eazydocs own table
            
            if ( get_option( 'eazydocspro_version' ) ) {
                update_option( 'eazydocspro_version', 'EAZYDOCSPRO_VERSION' );
                update_option( 'eazydocspro_update_notice', true );
            }
        
        }
        
        /**
         * eazydocspro_update_notice
         */
        public function eazydocspro_update_notice()
        {
            
            if ( get_option( 'eazydocspro_update_notice' ) ) {
                ?>
				<div class="notice notice-success is-dismissible">
					<p><?php 
                _e( 'EazyDocs Pro has been updated. We have merged the docs views meta to eazydocs own table.', 'eazydocs-pro' );
                ?></p>
				</div>
				<?php 
                delete_option( 'eazydocspro_update_notice' );
            }
        
        }
    
    }
}

/**
 * @return EazyDocs|false
 */

if ( !function_exists( 'eazydocspro' ) ) {
    /**
     * Load eazydocs
     *
     * Main instance of eazydocs
     *
     */
    function eazydocspro()
    {
        return EazyDocsPro::init();
    }
    
    /**
     * Kick of the plugin
     */
    eazydocspro();
}
